Crate libdd_dogstatsd_client

Crate libdd_dogstatsd_client 

dogstatsd-client implements a client to emit metrics to a dogstatsd server. This is made use of in at least the data-pipeline and sidecar crates.

Structs

Client
A dogstatsd-client that flushes stats to a given endpoint.

Enums

DogStatsDAction
The DogStatsDAction enum gathers the metric types that can be sent to the DogStatsD server.
DogStatsDActionOwned
The DogStatsDActionOwned enum gathers the metric types that can be sent to the DogStatsD server. This type takes ownership of the relevant data to support the sidecar better. For documentation on the dogstatsd metric types: https://docs.datadoghq.com/metrics/types/?tab=count#metric-types

Functions

new
Build a new flusher instance pointed at the provided endpoint. Returns error if the provided endpoint is not valid.