pub enum DogStatsDAction<'a, T: AsRef<str>, V: IntoIterator<Item = &'a Tag>> {
Count(T, i64, V),
Distribution(T, f64, V),
Gauge(T, f64, V),
Histogram(T, f64, V),
Set(T, i64, V),
}Expand description
The DogStatsDAction enum gathers the metric types that can be sent to the DogStatsD server.
Variants
Count(T, i64, V)
Distribution(T, f64, V)
Gauge(T, f64, V)
Histogram(T, f64, V)
Set(T, i64, V)
Cadence only support i64 type as value but Golang implementation uses string (https://github.com/DataDog/datadog-go/blob/331d24832f7eac97b091efd696278fe2c4192b29/statsd/statsd.go#L230) and PHP implementation uses float or string (https://github.com/DataDog/php-datadogstatsd/blob/0efdd1c38f6d3dd407efbb899ad1fd2e5cd18085/src/DogStatsd.php#L251)